#ifndef CIRCLESHAPE_CLASS
#define CIRCLESHAPE_CLASS

#include "shape.h"

// declaration of CircleShape class with base class Shape
class CircleShape: public Shape
{
   private:
      double radius;

   public:
      // arguments for the base point, radius and color
      CircleShape(double x = 0.0, double y = 0.0,
                  double r = 0.0, ShapeColor c = darkgray);

      // radius access methods
      double getRadius() const;
      void setRadius(double r);

      // draw the circle
      virtual void draw();

};

// ***********************************************************
//      CircleShape class implementation
// ***********************************************************

CircleShape::CircleShape(double x, double y, double r,
                     ShapeColor c): Shape(x,y,c), radius(r)
{}

// read the radius value; return value of private radius data
double CircleShape::getRadius() const
{
   return radius;
}

// change the radius value of the current object
void CircleShape::setRadius(double r)
{
   radius = r;          // assign r as the new radius
}

// draw the CircleShape with center at (x,y), given radius
// and color
void CircleShape::draw()
{
   EZDCOLORVAL old_color;
   
   old_color = ezdSetColor(getColor().convertToEzdColor());
   setHandle(ezdDrawCircle(getX(), getY(), radius));
   ezdSetColor(old_color);
}

#endif   // CIRCLESHAPE_CLASS
