#ifndef RECTANGLESHAPE_CLASS
#define RECTANGLESHAPE_CLASS

#include "shape.h"

// declaration of RectShape class with base class shape
class RectShape: public Shape
{
   private:
      double length, width;

   public:
      // constructor. has parameters for the base point,
      // length, width and color
      RectShape(double x = 0.0, double y = 0.0,
                double len = 0.0, double wid = 0.0,
                ShapeColor c = darkgray);

      // rectangle data access methods
      double getLength() const;
      double getWidth() const;
      void setSides(double len, double wid);

      // draw the rectangle
      virtual void draw();
};

// ***********************************************************
//      RectShape class implementation
// ***********************************************************

RectShape::RectShape(double x, double y, double len, double wid,
                     ShapeColor c):
            Shape(x,y,c), length(len), width(wid)
{}

double RectShape::getLength() const
{
   return length;
}

double RectShape::getWidth() const
{
   return width;
}

void RectShape::setSides(double len, double wid)
{
   length = len;
   width = wid;
}

void RectShape::draw()
{
   EZDCOLORVAL old_color;
   
   old_color = ezdSetColor(getColor().convertToEzdColor());

   // execute primitive function and draw the rectangle
   setHandle(ezdDrawRectangle(getX(), getY(),
                                   getX()+length,getY()+width));

   ezdSetColor(old_color);
}

#endif   // RECTANGLESHAPE_CLASS
