#ifndef REGPOLYGONSHAPE_CLASS
#define REGPOLYGONSHAPE_CLASS

#include "shape.h"

//using namespace std;

// declaration of polygonShape class with base class Shape
class RegPolyShape: public Shape
{
   private:
      int n;            // number of sides
      double length;    // length of each side

      // x and y-coordinates of the vertices
      vector<double> point_X;
      vector<double> point_Y;

      // construct the vertices
      void buildPoints();

   public:
      // constructor. has arguments for the base point,
      // number of sides, the length of each side and the
      // color
      RegPolyShape(double x = 0.0, double y = 0.0,
                int numsides = 4, double len = 0.0,
                ShapeColor c = darkgray);

      // retrieve or set length of a side
      double getLength() const;
      void setLength(double len);

      // retrieve or set number of sides
      int getN();
      void setN(int numsides);

      // draw the polygon
      virtual void draw();
};

#include <math.h>

// ***********************************************************
//      PolyShape class implementation
// ***********************************************************

void RegPolyShape::buildPoints()
{
   int side;
   double theta, d;
   const double PI = 3.141592653589793,
                DELTA_THETA = (2.0*PI)/n;

   // allocate space for the n coordinates
   point_X.resize(n);
   point_Y.resize(n);

   d = length/(2.0*sin(PI/n));
   theta = 0.0;
   for(side = 0; side < n; side++)
   {
      point_X[side] = getX() + d*cos(theta);
      point_Y[side] = getY() - d*sin(theta);
      theta += DELTA_THETA;
   }
}

// initialize base class, the number of sides
// and the length of each side
RegPolyShape::RegPolyShape(double x, double y, int numsides,
                     double len, ShapeColor c):
         Shape(x,y,c), n(numsides), length(len),
         point_X(0), point_Y(0)
{}

double RegPolyShape::getLength() const
{
   return length;
}

// change the length of a side
void RegPolyShape::setLength(double len)
{
   length = len;
}

int RegPolyShape::getN()
{
   return n;
}

void RegPolyShape::setN(int numsides)
{
   n = numsides;
}

void RegPolyShape::draw()
{
   EZDCOLORVAL old_color;
   
   // build the polygon's points and draw it
   buildPoints();
   old_color = ezdSetColor(getColor().convertToEzdColor());
   double *X = (double *) malloc(n*sizeof(double));
   double *Y = (double *) malloc(n*sizeof(double));
   for (int i=0; i<n; i++) X[i]=point_X[i];
   for (int i=0; i<n; i++) Y[i]=point_Y[i];
   setHandle(ezdDrawPolygon(n, X, Y));
   delete X;
   delete Y;
   ezdSetColor(old_color);
}

#endif   // REGPOLYGONSHAPE_CLASS
